(* This file is part of CodeTransformer - a tool for manipulating IDL and C++ files.
   Copyright (C) 1999 ANOQ of the Sun (alias Johnny Andersen)

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   I reserve the right to alter the license in future versions of CodeTransformer.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

   You can get this software from http://www.HardcoreProcessing.com/
   E-mail: anoq@HardcoreProcessing.com
*)

structure ctCPPAbsSyn =
  struct
    datatype tScopedName =
      scopedName of string list

      (* Typesystem *)
      (* Basic types *)
    datatype floatPtType =
      FLOAT
    | DOUBLE
    | LONGDOUBLE

      (* Integer types *)
    datatype sizedIntType =
      SHORT
    | LONG
    | LONGLONG
    | INT
    | CHAR
    | WCHART

    datatype intType =
      signedInt of sizedIntType
    | unsignedInt of sizedIntType
      (* End integer types *)

    datatype baseTypeSpec =
      integerType of intType
    | floatingPtType of floatPtType
    | BOOL

    datatype paramTypeSpec =
      paramBaseTypeSpec of baseTypeSpec
    | paramScopedName of tScopedName
    | paramPtrSpec of paramTypeSpec
    | paramRefSpec of paramTypeSpec

    datatype paramDcl =
      parameterDcl of paramTypeSpec * string

      (* End typesystem *)

    datatype methodType =
      mtConstructor
    | mtDestructor
    | mtMethod of paramTypeSpec option
  
    datatype export =
      opDcl of bool * methodType *
               string * (paramDcl list) * string
    | publicFlag
    | privateFlag
    | protectedFlag
    | NOEXPORT

    datatype claBody =
      classBody of export list
  
    datatype inhSpec =
      (* Boolean flags for public and virtual specifiers*)
      inheritanceSpec of (bool * bool * tScopedName) list

    datatype claHead =
      classHeader of string * inhSpec

    datatype cla =
      classForward of string
    | classDcl of claHead * claBody

    datatype def =
      class of cla
    | nameSpace of string * def list
    | preprocess of string
    | ppInclude of string
    | UNDEF
    
    datatype spec =
      specification of def list
  end