(* This file is part of CodeTransformer - a tool for manipulating IDL and C++ files.
   Copyright (C) 1999 ANOQ of the Sun (alias Johnny Andersen)

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   I reserve the right to alter the license in future versions of CodeTransformer.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

   You can get this software from http://www.HardcoreProcessing.com/
   E-mail: anoq@HardcoreProcessing.com
*)

structure ctCPPBPrettyPrint : CT_PRETTY_PRINT =
  struct
    structure absy = ctCPPAbsSyn
    type t = absy.spec
    structure g = ctFCPPPrettyPrint(structure absy = absy)

    type config = bool

    fun printOpInh outF space absy.mtConstructor ((_, _, scopedName)::rest) first =
          (if first then outF " : " else outF ", ";
           g.printScopedName outF scopedName; outF "()")
      | printOpInh _ _ _ _ _ =
          ()

    fun printExport outF space className inhSpec (absy.opDcl(isVirtual, opType, name, params, bodyText) ) =
          (g.lineFeed outF space; g.lineFeed outF space;
           g.printMethodType outF (className ^ "::") opType;
           outF (name ^ "(");
           g.printParamDcls outF true params;
           outF ")";
           printOpInh outF space opType inhSpec true;
           g.lineFeed outF space; outF "{"; g.lineFeed outF space;
           outF bodyText; outF "}")
      | printExport _ _ _ _ _ =
          () (* Do not print NOEXPORT, publicFlag, privateFlag or protectedFlag *)
           

    fun printClassBody outF space className inhSpec (absy.classBody(exportList)) =
          (map (printExport outF space className inhSpec) exportList;())

    fun getClassName space (absy.classHeader(name, _)) =
          (name)

    fun getInhSpec (absy.classHeader(_, absy.inheritanceSpec(spec))) =
          spec

    fun printClass outF space (absy.classForward(_)) =
          ()
      | printClass outF space (absy.classDcl(head, body)) =
          (printClassBody
             outF space (getClassName space head)
             (getInhSpec head) body)

    fun printNameSpace outF space (name, defList) =
          (g.lineFeed outF space;
           outF ("namespace " ^ name);
           g.lineFeed outF space; outF "{";
           map (printDef outF (space ^ "  ")) defList;
           g.lineFeed outF space; outF "};")

    and printDef outF space (absy.class(value)) =
          (printClass outF space (value))
      | printDef outF space (absy.nameSpace(value)) =
          (printNameSpace outF space (value))
      | printDef outF space (absy.preprocess(value)) =
          ()
      | printDef outF space (absy.ppInclude(value)) =
          ()
      | printDef outF space (absy.UNDEF) =
          ()

    fun prettyPrint _ outF (absy.specification(value) ) =
          (map (printDef outF "") value; g.lineFeed outF "")
  end