(* This file is part of CodeTransformer - a tool for manipulating IDL and C++ files.
   Copyright (C) 1999 ANOQ of the Sun (alias Johnny Andersen)

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   I reserve the right to alter the license in future versions of CodeTransformer.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

   You can get this software from http://www.HardcoreProcessing.com/
   E-mail: anoq@HardcoreProcessing.com
*)

structure ctCPPHPrettyPrint : CT_PRETTY_PRINT =
  struct
    structure absy = ctCPPAbsSyn
    type t = absy.spec
    structure g = ctFCPPPrettyPrint(structure absy = absy)

    type config = bool

    fun tryTrim str =
          gnLexMisc.trimlr 0 2 str

    fun printExport outF space absy.NOEXPORT =
          ()
      | printExport outF space (absy.opDcl(isVirtual, opType, name, params, _) ) =
          (g.lineFeed outF space;
           if isVirtual then outF "virtual " else ();
           g.printMethodType outF "" opType;
           outF (name ^ "(");
           g.printParamDcls outF true params;
           outF ");")
      | printExport outF space absy.publicFlag =
          (g.lineFeed outF (tryTrim space);
           outF "public:")
      | printExport outF space absy.privateFlag =
          (g.lineFeed outF (tryTrim space);
           outF "private:")
      | printExport outF space absy.protectedFlag =
          (g.lineFeed outF (tryTrim space);
           outF "protected:")

    fun printClassBody outF space (absy.classBody(exportList)) =
          (g.lineFeed outF space; outF "{";
           map (printExport outF (space ^ "  ")) exportList;
           g.lineFeed outF space; outF "};")

    fun printInhSpec conf outF _ nil =
          ()
      | printInhSpec conf outF first ((isPublic, isVirtual, ancestor)::rest) =
          ((if first then
              outF " : "
            else
              outF ", ");
           (if isPublic andalso isVirtual andalso conf then
              outF "implements("
            else
              ((if isPublic then
                  outF "public "
                else
                  ());
               (if isVirtual then
                  outF "virtual "
                else
                  ())));
           g.printScopedName outF ancestor;
           if isPublic andalso isVirtual andalso conf then outF ")" else ();
           printInhSpec conf outF false rest) 

    fun printClassHead conf outF space (absy.classHeader(name,
                                absy.inheritanceSpec(inhSpec))) =
          (g.lineFeed outF space;
           outF ("class " ^ name);
           printInhSpec conf outF true inhSpec)

    fun printClass _ outF space (absy.classForward(name)) =
          (g.lineFeed outF space;
           outF ("class " ^ name ^ ";"))
      | printClass conf outF space (absy.classDcl(head, body)) =
          (printClassHead conf outF space head;
           printClassBody outF space body)

    datatype defType =
      defPreprocess
    | defInclude
    | defClassForward
    | defClass
    | defNameSpace
    | defNone

    fun checkLineFeed outF space lastPrinted printNow =
          if lastPrinted = printNow orelse
             lastPrinted = defNone then
            ()
          else
            g.lineFeed outF space

    fun printNameSpace conf outF space (name, defList) =
          (g.lineFeed outF space;
           outF ("namespace " ^ name);
           g.lineFeed outF space; outF "{";
           foldl (printDef conf outF (space ^ "  ")) defNone defList;
           g.lineFeed outF space; outF "};")

    and printDef conf outF space (absy.class(value), lastPrinted) =
          (checkLineFeed outF space lastPrinted defClass;
           printClass conf outF space (value); defClass)
      | printDef conf outF space (absy.nameSpace(value), lastPrinted) =
          (checkLineFeed outF space lastPrinted defNameSpace;
           printNameSpace conf outF space (value); defNameSpace)
      | printDef _ outF space (absy.preprocess(value), lastPrinted) =
          (checkLineFeed outF space lastPrinted defPreprocess;
           g.lineFeed outF space; outF "#"; outF value; defPreprocess)
      | printDef _ outF space (absy.ppInclude(value), lastPrinted) =
          (checkLineFeed outF space lastPrinted defInclude;
           g.lineFeed outF space; outF "#include "; outF value; defInclude)
      | printDef _ outF space (absy.UNDEF, lastPrinted) =
          (defNone)

    fun prettyPrint conf outF (absy.specification(value) ) =
          (foldl (printDef conf outF "") defNone value; g.lineFeed outF "")
  end
