(* This file is part of CodeTransformer - a tool for manipulating IDL and C++ files.
   Copyright (C) 1999 ANOQ of the Sun (alias Johnny Andersen)

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   I reserve the right to alter the license in future versions of CodeTransformer.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

   You can get this software from http://www.HardcoreProcessing.com/
   E-mail: anoq@HardcoreProcessing.com
*)

functor ctFCPPKey(structure Tokens : ctCPP_TOKENS) =
  struct
    (* FIXME: Do this right... fun fl (pos, rg) = gnLexMisc.fLoc (pos, rg);*)
    fun fl (pos, rg) = (pos, pos + rg);
    fun vfl (value, pos, rg) = (value, pos, pos + rg);

    fun keyword (yytext, yypos) =
      let
        open Tokens
      in
        case yytext of
          "and"        => (AND( fl (yypos, 3)))
        | "bool"       => (BOOL( fl (yypos, 4)))
        | "compl"      => (COMPL( fl (yypos, 5)))
        | "do"         => (DO( fl (yypos, 2)))
        | "export"     => (EXPORT( fl (yypos, 6)))
        | "goto"       => (GOTO( fl (yypos, 4)))
        | "namespace"  => (NAMESPACE( fl (yypos, 9)))
        | "or_eq"      => (OREQ( fl (yypos, 5)))
        | "return"     => (RETURN( fl (yypos, 6)))
        | "struct"     => (STRUCT( fl (yypos, 6)))
        | "try"        => (TRY( fl (yypos, 3)))
        | "using"      => (USING( fl (yypos, 5)))
        | "xor"        => (XOR( fl (yypos, 3)))
        | "and_eq"     => (ANDEQ( fl (yypos, 6)))
        | "break"      => (BREAK( fl (yypos, 5)))
        | "const"      => (CONST( fl (yypos, 5)))
        | "double"     => (DOUBLE( fl (yypos, 6)))
        | "extern"     => (EXTERN( fl (yypos, 6)))
        | "if"         => (IF( fl (yypos, 2)))
        | "new"        => (NEW( fl (yypos, 3)))
        | "private"    => (PRIVATE( fl (yypos, 7)))
        | "short"      => (SHORT( fl (yypos, 5)))
        | "switch"     => (SWITCH( fl (yypos, 6)))
        | "typedef"    => (TYPEDEF( fl (yypos, 7)))
        | "virtual"    => (VIRTUAL( fl (yypos, 7)))
        | "xor_eq"     => (XOREQ( fl (yypos, 6)))
        | "asm"        => (ASM( fl (yypos, 3)))
        | "case"       => (CASE( fl (yypos, 4)))
        | "const_cast" => (CONSTCAST( fl (yypos, 10)))
        | "dynamic_cast" => (DYNAMICCAST( fl (yypos, 12)))
        | "false"      => (FALSE( fl (yypos, 5)))
        | "inline"     => (INLINE( fl (yypos, 6)))
        | "not"        => (NOT( fl (yypos, 3)))
        | "protected"  => (PROTECTED( fl (yypos, 9)))
        | "signed"     => (SIGNED( fl (yypos, 6)))
        | "template"   => (TEMPLATE( fl (yypos, 8)))
        | "typeid"     => (TYPEID( fl (yypos, 6)))
        | "void"       => (VOID( fl (yypos, 4)))
        | "auto"       => (AUTO( fl (yypos, 4)))
        | "catch"      => (CATCH( fl (yypos, 5)))
        | "continue"   => (CONTINUE( fl (yypos, 8)))
        | "else"       => (ELSE( fl (yypos, 4)))
        | "float"      => (FLOAT( fl (yypos, 5)))
        | "int"        => (INT( fl (yypos, 3)))
        | "not_eq"     => (NOTEQ( fl (yypos, 6)))
        | "public"     => (PUBLIC( fl (yypos, 6)))
        | "sizeof"     => (SIZEOF( fl (yypos, 6)))
        | "this"       => (THIS( fl (yypos, 4)))
        | "typename"   => (TYPENAME( fl (yypos, 8)))
        | "volatile"   => (VOLATILE( fl (yypos, 8)))
        | "bitand"     => (BITAND( fl (yypos, 6)))
        | "char"       => (CHAR( fl (yypos, 4)))
        | "default"    => (DEFAULT( fl (yypos, 7)))
        | "enum"       => (ENUM( fl (yypos, 4)))
        | "for"        => (FOR( fl (yypos, 3)))
        | "long"       => (LONG( fl (yypos, 4)))
        | "operator"   => (OPERATOR( fl (yypos, 8)))
        | "register"   => (REGISTER( fl (yypos, 8)))
        | "static"     => (STATIC( fl (yypos, 6)))
        | "throw"      => (THROW( fl (yypos, 5)))
        | "union"      => (UNION( fl (yypos, 5)))
        | "wchar_t"    => (WCHART( fl (yypos, 7)))
        | "bitor"      => (BITOR( fl (yypos, 5)))
        | "class"      => (CLASS( fl (yypos, 5)))
        | "delete"     => (DELETE( fl (yypos, 6)))
        | "explicit"   => (EXPLICIT( fl (yypos, 8)))
        | "friend"     => (FRIEND( fl (yypos, 6)))
        | "mutable"    => (MUTABLE( fl (yypos, 7)))
        | "or"         => (OR( fl (yypos, 2)))
        | "reinterpret_cast" => (REINTERPRETCAST( fl (yypos, 16)))
        | "static_cast" => (STATICCAST( fl (yypos, 11)))
        | "true"       => (TRUE( fl (yypos, 4)))
        | "unsigned"   => (UNSIGNED( fl (yypos, 8)))
        | "while"      => (WHILE( fl (yypos, 9)))

          (* identifier *)
        | _            => (ident(vfl (yytext, yypos, size yytext)))
      end (* let *)
  end