(* This file is part of CodeTransformer - a tool for manipulating IDL and C++ files.
   Copyright (C) 1999 ANOQ of the Sun (alias Johnny Andersen)

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   I reserve the right to alter the license in future versions of CodeTransformer.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

   You can get this software from http://www.HardcoreProcessing.com/
   E-mail: anoq@HardcoreProcessing.com
*)

functor ctFCPPPrettyPrint(structure absy : CT_CPP_ABS_SYN) =
  struct
    fun lineFeed outF space =
          outF ("\n" ^ space)

    fun printScopedNames outF first nil =
          if first then
            gnE.gnRaiseGeneric("CPPSyntaxTree", "Scoped name is empty!")
          else
            ()
      | printScopedNames outF first (name::rest) =
          (if first then
             outF name
           else
             outF ("::" ^ name);
           printScopedNames outF false rest)

    fun printScopedName outF (absy.scopedName(value)) =
          printScopedNames outF true value

    fun printFloatingPtType outF absy.FLOAT =
          outF "float"
      | printFloatingPtType outF absy.DOUBLE =
          outF "double"
      | printFloatingPtType outF absy.LONGDOUBLE =
          outF "long double"

    fun printSizedIntType outF absy.SHORT =
          outF "short"
      | printSizedIntType outF absy.LONG =
          outF "long"
      | printSizedIntType outF absy.LONGLONG =
          outF "long long"
      | printSizedIntType outF absy.INT =
          outF "int"
      | printSizedIntType outF absy.CHAR =
          outF "char"
      | printSizedIntType outF absy.WCHART =
          outF "wchar_t"

    fun printIntegerType outF (absy.signedInt(value)) =
          printSizedIntType outF value
      | printIntegerType outF (absy.unsignedInt(value)) =
          (outF "unsigned "; printSizedIntType outF value)

    fun printBaseTypeSpec outF (absy.integerType(value)) =
          printIntegerType outF value
      | printBaseTypeSpec outF (absy.floatingPtType(value)) =
          printFloatingPtType outF value
      | printBaseTypeSpec outF (absy.BOOL) =
          outF "bool"

    fun printParamTypeSpec outF (absy.paramBaseTypeSpec(value)) =
          (printBaseTypeSpec outF value; outF " ")
      | printParamTypeSpec outF (absy.paramScopedName(value)) =
          (printScopedName outF value; outF " ")
      | printParamTypeSpec outF (absy.paramPtrSpec(value)) =
          (printParamTypeSpec outF value; outF "*")
      | printParamTypeSpec outF (absy.paramRefSpec(value)) =
          (printParamTypeSpec outF value; outF "&")

    fun printParamDcls outF first nil =
          (if first then
             outF "void"
           else
             ())
      | printParamDcls outF first ((absy.parameterDcl(typeSpec, name))::rest) =
          ((if first then
              ()
            else
              outF ", ");
           printParamTypeSpec outF typeSpec;
           outF name;
           printParamDcls outF false rest)
    
    fun printMethodType outF methodPrefix absy.mtConstructor =
          outF methodPrefix
      | printMethodType outF methodPrefix absy.mtDestructor =
          outF (methodPrefix ^ "~")
      | printMethodType outF methodPrefix (absy.mtMethod(NONE)) =
          outF ("void " ^ methodPrefix)
      | printMethodType outF methodPrefix (absy.mtMethod(SOME(retType))) =
          (printParamTypeSpec outF retType;
           outF methodPrefix)
  end