(* This file is part of CodeTransformer - a tool for manipulating IDL and C++ files.
   Copyright (C) 1999 ANOQ of the Sun (alias Johnny Andersen)

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   I reserve the right to alter the license in future versions of CodeTransformer.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

   You can get this software from http://www.HardcoreProcessing.com/
   E-mail: anoq@HardcoreProcessing.com
*)

structure ctCommands :> CT_COMMANDS =
  struct
    exception Internal

    type t = (string * string * (string list -> bool)) list

    val init = nil : t
    
    fun addCommand commands name description f =
          (name, description, f)::commands

    fun displayPrompt () =
          print "CodeTransformer> "

    fun findAndExecute nil name _ =
          (print ("Unknown command: " ^ name ^ "\n"); true)
      | findAndExecute ((fName, _, f)::commands) name argList =   
          if fName = name then
            gnE.checkedExec f argList true
          else
            findAndExecute commands name argList

    fun execute commands input =
          let
            val tokens = String.tokens
                  (fn a => a = #" " orelse a = #"\t" orelse a = #"\n")
                  input
          in
            if tokens = nil then
              true
            else
              findAndExecute
                commands
                (hd tokens) (tl tokens)
          end

    fun run commands =
          let
            val _ = TextIO.flushOut
            val _ = displayPrompt ()
            val _ = TextIO.flushOut
            val line = TextIO.inputLine TextIO.stdIn
          in
            if not (execute commands line) orelse
               (TextIO.flushOut; TextIO.endOfStream TextIO.stdIn) then
              ()
            else
              run commands
          end

    fun displayCommand (name, desc, _) =
          print ("* " ^ name ^ ": " ^ desc ^ "\n")

    (* FIXME: Make this a higher order function traversing command data... *)
    fun displayCommands commands =
          (map displayCommand commands; ())
  end
