(* This file is part of CodeTransformer - a tool for manipulating IDL and C++ files.
   Copyright (C) 1999 ANOQ of the Sun (alias Johnny Andersen)

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   I reserve the right to alter the license in future versions of CodeTransformer.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

   You can get this software from http://www.HardcoreProcessing.com/
   E-mail: anoq@HardcoreProcessing.com
*)

signature CT_CONFIG =
  sig
    type t

    val readFile : string -> t
    val getItem : t -> string -> string -> string
  end

structure ctConfig :> CT_CONFIG =
  struct
    type t = (string * string) list

    fun stripLine subStr =
          if Substring.sub(subStr, (Substring.size subStr) - 1) = #"\n" then
            Substring.slice(subStr, 1, SOME((Substring.size subStr) - 2))
          else
            Substring.slice(subStr, 1, NONE)

    fun readConfig inStr conf =
          if TextIO.endOfStream inStr then
            conf
          else
            let
              val line = TextIO.inputLine inStr
              val (key, value) =
                    Substring.splitl
                      (fn a => a <> #"=")
                      (Substring.all line)
            in
              readConfig inStr
                ((Substring.string key,
                  Substring.string
                    (stripLine value
                    ))::conf)
            end

    fun readFile fileName =
          let
            val inStr = TextIO.openIn fileName
          in
            gnUtil.finalize
              (fn _ => readConfig inStr nil)
              (fn _ => TextIO.closeIn inStr)
          end
  
    fun getItem nil _ default =
          default
      | getItem ((fKey, value)::conf) key default =
          if fKey = key then
            value
          else
            getItem conf key default
  end
