(* This file is part of CodeTransformer - a tool for manipulating IDL and C++ files.
   Copyright (C) 1999 ANOQ of the Sun (alias Johnny Andersen)

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   I reserve the right to alter the license in future versions of CodeTransformer.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

   You can get this software from http://www.HardcoreProcessing.com/
   E-mail: anoq@HardcoreProcessing.com
*)

structure ctIDLAbsSyn =
  struct
    datatype tScopedName =
      scopedName of string list

      (* Typesystem *)
      (* Basic types *)
    datatype floatPtType =
      FLOAT
    | DOUBLE
    | LONGDOUBLE

      (* Integer types *)
    datatype sizedIntType =
      SHORT
    | LONG
    | LONGLONG

    datatype intType =
      signedInt of sizedIntType
    | unsignedInt of sizedIntType
      (* End integer types *)

    datatype baseTypeSpec =
      integerType of intType
    | floatingPtType of floatPtType
    | CHAR
    | WCHAR
    | BOOLEAN
    | OCTET
    | ANY
      (* End basic types *)

    datatype paramTypeSpec =
      paramBaseTypeSpec of baseTypeSpec
    | paramStringType of int option
    | paramWStringType of int option
    | paramFixedPtType of int * int
    | paramScopedName of tScopedName

    datatype paramAttr =
      IN
    | OUT
    | INOUT

    datatype paramDcl =
      parameterDcl of paramAttr * paramTypeSpec * string

      (* End typesystem *)
  
    datatype export =
      opDcl of (paramTypeSpec option) * string *
               (paramDcl list) * (unit option) * (unit option)
    | attrDcl of bool * paramTypeSpec * (string list)
    | NOEXPORT

    datatype interfBody =
      interfaceBody of export list
  
    datatype inhSpec =
      inheritanceSpec of tScopedName list

    datatype interfHead =
      interfaceHeader of string * inhSpec

    datatype interf =
      interfaceForward of string
    | interfaceDcl of interfHead * interfBody

    datatype def =
      interface of interf
    | module of string * def list
    | preprocess of string
    | ppInclude of string
    | UNDEF
    
    datatype spec =
      specification of def list
  end