(* This file is part of CodeTransformer - a tool for manipulating IDL and C++ files.
   Copyright (C) 1999 ANOQ of the Sun (alias Johnny Andersen)

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   I reserve the right to alter the license in future versions of CodeTransformer.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

   You can get this software from http://www.HardcoreProcessing.com/
   E-mail: anoq@HardcoreProcessing.com
*)

functor ctFIDLKey(structure Tokens : ctIDL_TOKENS) =
  struct
    (* FIXME: Do this right... fun fl (pos, rg) = gnLexMisc.fLoc (pos, rg);*)
    fun fl (pos, rg) = (pos, pos + rg);
    fun vfl (value, pos, rg) = (value, pos, pos + rg);

    fun keyword (yytext, yypos) =
      let
        open Tokens
      in
        case yytext of
          "any"        => (ANY( fl(yypos, 3)))
        | "double"     => (DOUBLE( fl (yypos, 6)))
        | "interface"  => (INTERFACE( fl (yypos, 9)))
        | "readonly"   => (READONLY( fl (yypos, 8)))
        | "unsigned"   => (UNSIGNED( fl (yypos, 8)))
        | "attribute"  => (ATTRIBUTE( fl (yypos, 9)))
        | "enum"       => (ENUM( fl (yypos, 4)))
        | "long"       => (LONG( fl (yypos, 4)))
        | "sequence"   => (SEQUENCE( fl (yypos, 8)))
        | "union"      => (UNION( fl (yypos, 5)))
        | "boolean"    => (BOOLEAN( fl (yypos, 7)))
        | "exception"  => (EXCEPTION( fl (yypos, 9)))
        | "module"     => (MODULE( fl (yypos, 6)))
        | "short"      => (SHORT( fl (yypos, 5)))
        | "void"       => (VOID( fl (yypos, 4)))
        | "case"       => (CASE( fl (yypos, 4)))
        | "FALSE"      => (FALSE( fl (yypos, 5)))
        | "Object"     => (OBJECT( fl (yypos, 6)))
        | "string"     => (STRING( fl (yypos, 6)))
        | "wchar"      => (WCHAR( fl (yypos, 5)))
        | "char"       => (CHAR( fl (yypos, 4)))
        | "fixed"      => (FIXED( fl (yypos, 5)))
        | "octet"      => (OCTET( fl (yypos, 5)))
        | "struct"     => (STRUCT( fl (yypos, 6)))
        | "wstring"    => (WSTRING( fl (yypos, 7)))
        | "const"      => (CONST( fl (yypos, 5)))
        | "float"      => (FLOAT( fl (yypos, 5)))
        | "oneway"     => (ONEWAY( fl (yypos, 6)))
        | "switch"     => (SWITCH( fl (yypos, 6)))
        | "context"    => (CONTEXT( fl (yypos, 7)))
        | "in"         => (IN( fl (yypos, 2)))
        | "out"        => (OUT( fl (yypos, 3)))
        | "TRUE"       => (TRUE( fl (yypos, 4)))
        | "default"    => (DEFAULT( fl (yypos, 7)))
        | "inout"      => (INOUT( fl (yypos, 5)))
        | "raises"     => (RAISES( fl (yypos, 6)))
        | "typedef"    => (TYPEDEF( fl (yypos, 7)))
        | "native"     => (NATIVE( fl (yypos, 6)))

          (* identifier *)
        | _            => (ident(vfl (yytext, yypos, size yytext)))
      end (* let *)

    val alphas  = ["any", "default", "inout", "out", "switch",
                   "attribute", "double", "interface", "raises",
                   "TRUE", "boolean", "enum", "long", "readonly",
                   "typedef", "case", "exception", "module",
                   "sequence", "unsigned", "char", "FALSE",
                   "Object", "short", "union", "const",
                   "float", "octet", "string", "void",
                   "context", "in", "oneway", "struct",
                   "wchar", "fixed", "wstring"];

    val punct = [";", "{", "}", ":", ",", "=", "+", "-",
                 "(", ")", "<", ">", "[", "]", "'", "\"",
                 "\\", "|", "^", "&", "*", "/", "%", "~"];

    val preprocess = ["#", "##", "|", "||", "&&"];
  end