(* This file is part of CodeTransformer - a tool for manipulating IDL and C++ files.
   Copyright (C) 1999 ANOQ of the Sun (alias Johnny Andersen)

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   I reserve the right to alter the license in future versions of CodeTransformer.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

   You can get this software from http://www.HardcoreProcessing.com/
   E-mail: anoq@HardcoreProcessing.com
*)

structure ctIDLParser (* FIXME: Correct this signature *) =
  struct
    structure ctIDLLrVals = ctIDLLrValsFun(
                              structure Token = LrParser.Token
                              structure ctIDLAbsSyn = ctIDLAbsSyn)
    structure ctIDLLex = ctIDLLexFun(
                           structure Tokens = ctIDLLrVals.Tokens)
    structure IDLParser = Join(structure ParserData = ctIDLLrVals.ParserData
			structure Lex=ctIDLLex
			structure LrParser = LrParser)
    
    fun parseFile filename =
      let
        val _ = gnErrorMsg.reset()
        val inFile = TextIO.openIn filename
      in
        gnUtil.finalize
          (fn _ =>
             let
               fun get _ = TextIO.input inFile
               fun parseError(s,p1,p2) = gnErrorMsg.error p1 s
               val lexer = LrParser.Stream.streamify
                     (ctIDLLex.makeLexer get)
               val (abssyn, _) = IDLParser.parse(15, lexer, parseError, ())
             in
               abssyn : ctIDLAbsSyn.spec
             end)
          (fn _ => TextIO.closeIn inFile)
      end
        handle LrParser.ParseError =>
          gnE.gnRaiseGeneric ("IDLParse", "Error occurred during parsing!")
  end