(* This file is part of CodeTransformer - a tool for manipulating IDL and C++ files.
   Copyright (C) 1999 ANOQ of the Sun (alias Johnny Andersen)

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   I reserve the right to alter the license in future versions of CodeTransformer.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

   You can get this software from http://www.HardcoreProcessing.com/
   E-mail: anoq@HardcoreProcessing.com
*)

structure ctMapIDLtoCPP =
  struct
    type fromLangSpec = ctIDLAbsSyn.spec
    type toLangSpec = ctCPPAbsSyn.spec
    type config = bool
    
    fun mScopedName (ctIDLAbsSyn.scopedName(value)) =
          ctCPPAbsSyn.scopedName(value)

      (* Typesystem *)
      (* Basic types *)
    fun mFloatPtType ctIDLAbsSyn.FLOAT =
          ctCPPAbsSyn.scopedName(["CORBA", "Float"])
      | mFloatPtType ctIDLAbsSyn.DOUBLE =
          ctCPPAbsSyn.scopedName(["CORBA", "Double"])
      | mFloatPtType ctIDLAbsSyn.LONGDOUBLE =
          ctCPPAbsSyn.scopedName(["CORBA", "LongDouble"])

      (* Integer types *)

    fun mIntType (ctIDLAbsSyn.signedInt(ctIDLAbsSyn.SHORT)) =
          ctCPPAbsSyn.scopedName(["CORBA", "Short"])
      | mIntType (ctIDLAbsSyn.signedInt(ctIDLAbsSyn.LONG)) =
          ctCPPAbsSyn.scopedName(["CORBA", "Long"])
      | mIntType (ctIDLAbsSyn.signedInt(ctIDLAbsSyn.LONGLONG)) =
          ctCPPAbsSyn.scopedName(["CORBA", "LongLong"])
      | mIntType (ctIDLAbsSyn.unsignedInt(ctIDLAbsSyn.SHORT)) =
          ctCPPAbsSyn.scopedName(["CORBA", "UShort"])
      | mIntType (ctIDLAbsSyn.unsignedInt(ctIDLAbsSyn.LONG)) =
          ctCPPAbsSyn.scopedName(["CORBA", "ULong"])
      | mIntType (ctIDLAbsSyn.unsignedInt(ctIDLAbsSyn.LONGLONG)) =
          ctCPPAbsSyn.scopedName(["CORBA", "ULongLong"])

    fun mBaseTypeSpec (ctIDLAbsSyn.integerType(value)) =
          mIntType(value)
      | mBaseTypeSpec (ctIDLAbsSyn.floatingPtType(value)) =
          mFloatPtType(value)
      | mBaseTypeSpec ctIDLAbsSyn.CHAR =
          ctCPPAbsSyn.scopedName(["CORBA", "Char"])
      | mBaseTypeSpec ctIDLAbsSyn.WCHAR =
          ctCPPAbsSyn.scopedName(["CORBA", "WChar"])
      | mBaseTypeSpec ctIDLAbsSyn.BOOLEAN =
          ctCPPAbsSyn.scopedName(["CORBA", "Boolean"])
      | mBaseTypeSpec ctIDLAbsSyn.OCTET =
          ctCPPAbsSyn.scopedName(["CORBA", "Octet"])
      | mBaseTypeSpec ctIDLAbsSyn.ANY =
          gnE.gnRaiseNotImplemented ("Type ANY is not supported!") (* FIXME: Correct this! *)
      (* End basic types *)


    fun mParamTypeSpec _ (ctIDLAbsSyn.paramBaseTypeSpec(value)) =
          ctCPPAbsSyn.paramScopedName( mBaseTypeSpec(value) )
      | mParamTypeSpec conf (ctIDLAbsSyn.paramStringType(_)) =
          ctCPPAbsSyn.paramScopedName(
            ctCPPAbsSyn.scopedName(["CORBA", "String"]) )
      | mParamTypeSpec conf (ctIDLAbsSyn.paramWStringType(_)) =
          ctCPPAbsSyn.paramScopedName(
            ctCPPAbsSyn.scopedName(["CORBA", "WString"]) )
      | mParamTypeSpec _ (ctIDLAbsSyn.paramFixedPtType(_)) =
          gnE.gnRaiseNotImplemented ("Type FixedPt is not supported!") (* FIXME: Correct this! *)
      | mParamTypeSpec _ (ctIDLAbsSyn.paramScopedName(value)) =
        (* For scoped names, pointers are just added, since this is common *)
          ctCPPAbsSyn.paramPtrSpec(
            ctCPPAbsSyn.paramScopedName( mScopedName(value) ))

    fun mParamAttr (ctIDLAbsSyn.IN, typeSpec) =
          typeSpec
      | mParamAttr (_, typeSpec) =
        (* For OUT and INOUT, references are just added *)
          ctCPPAbsSyn.paramRefSpec(typeSpec)

    fun mParamDcl conf (ctIDLAbsSyn.parameterDcl(paramAttr, paramTS, ident)) =
          ctCPPAbsSyn.parameterDcl(
            mParamAttr(paramAttr, mParamTypeSpec conf (paramTS)), ident )
    
      (* End typesystem *)
  
    fun addAttrMethods conf (readonly, typeSpec) (name, accList) =
          let
            val accList = 
                  (ctCPPAbsSyn.opDcl(true,
                     ctCPPAbsSyn.mtMethod(SOME(mParamTypeSpec conf typeSpec)),
                     name, nil, ""))::accList
          in
            if readonly then
              accList
            else
              (ctCPPAbsSyn.opDcl(true,
                 ctCPPAbsSyn.mtMethod(NONE), name,
                 [ctCPPAbsSyn.parameterDcl(
                    mParamTypeSpec conf typeSpec, "_value")], ""))::accList
          end

    fun mFoldExport conf (ctIDLAbsSyn.opDcl(NONE, name, params, _, _), rest ) =
          (ctCPPAbsSyn.opDcl(true, ctCPPAbsSyn.mtMethod(NONE), name, map (mParamDcl conf) params, ""))::rest
      | mFoldExport conf (ctIDLAbsSyn.opDcl(SOME(retTypeSpec), name, params, _, _), rest ) =
          (ctCPPAbsSyn.opDcl(true, ctCPPAbsSyn.mtMethod(SOME(mParamTypeSpec conf retTypeSpec)),
                             name, map (mParamDcl conf) params, ""))::rest
      | mFoldExport conf (ctIDLAbsSyn.attrDcl(readonly, typeSpec, names), rest ) =
          (* Here is the mapping of attributes to methods... *)
          foldl (addAttrMethods conf (readonly, typeSpec)) rest names
      | mFoldExport _ (ctIDLAbsSyn.NOEXPORT, rest ) =
          (ctCPPAbsSyn.NOEXPORT)::rest

    fun mInterfaceBody conf className (ctIDLAbsSyn.interfaceBody(value) ) =
          ctCPPAbsSyn.classBody(ctCPPAbsSyn.publicFlag::
                                ctCPPAbsSyn.opDcl(false, ctCPPAbsSyn.mtConstructor, className, nil, "")::
                                ctCPPAbsSyn.opDcl(true, ctCPPAbsSyn.mtDestructor, className, nil, "")::
                                (foldr (mFoldExport conf) nil value))

    fun mInhSpec (ctIDLAbsSyn.inheritanceSpec(value) ) =
          (* Notice: Inheritance is made public and virtual *)
          ctCPPAbsSyn.inheritanceSpec(
            map (fn scName => (true, true, mScopedName(scName))) value)

    fun mInterfaceHead (ctIDLAbsSyn.interfaceHeader(name, inh) ) =
          ctCPPAbsSyn.classHeader(name, mInhSpec(inh) )

    fun mGetInterfaceName (ctIDLAbsSyn.interfaceHeader(name, _) ) =
          name

    fun mInterface _ (ctIDLAbsSyn.interfaceForward(value) ) =
          ctCPPAbsSyn.classForward(value)
      | mInterface conf (ctIDLAbsSyn.interfaceDcl(head, body) ) =
          ctCPPAbsSyn.classDcl(
            mInterfaceHead(head),
            mInterfaceBody conf (mGetInterfaceName head) (body))

    fun mDef conf (ctIDLAbsSyn.interface(value)) =
          ctCPPAbsSyn.class( mInterface conf (value) )
      | mDef conf (ctIDLAbsSyn.module(name, defList)) =
          ctCPPAbsSyn.nameSpace(name, map (mDef conf) defList)
      | mDef _ (ctIDLAbsSyn.preprocess(value)) =
          ctCPPAbsSyn.preprocess( value )
      | mDef _ (ctIDLAbsSyn.ppInclude(value)) =
          ctCPPAbsSyn.ppInclude( value )
      | mDef _ (ctIDLAbsSyn.UNDEF) =
          ctCPPAbsSyn.UNDEF

    fun languageMap conf (ctIDLAbsSyn.specification(value) ) =
          ctCPPAbsSyn.specification(map (mDef conf) value)
  end