(* This file is part of CodeTransformer - a tool for manipulating IDL and C++ files.
   Copyright (C) 1999 ANOQ of the Sun (alias Johnny Andersen)

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   I reserve the right to alter the license in future versions of CodeTransformer.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

   You can get this software from http://www.HardcoreProcessing.com/
   E-mail: anoq@HardcoreProcessing.com
*)

(*require "gnexceptions_sig";
require "$.basis.__text_io.sml";*)

structure gnE : GN_E =
  struct
    datatype t =
      generic
    | bug
    | notImplemented

    exception Generic of (t * string * string) list

    fun gnRaise value =
          raise Generic([value])

    fun gnRaiseBug value =
          gnRaise (bug, "", value)

    fun gnRaiseGeneric (valueType, value) =
          gnRaise (generic, valueType, value)

    fun gnRaiseNotImplemented value =
          gnRaise (notImplemented, "", value)

    fun reRaise (Generic(values)) newValue =
          raise Generic(newValue::values)
      | reRaise _ newValue =
          raise Generic(newValue::[(bug, "",
            "gnE.reRaise used with an exception which is not of type Generic!")])

    fun outputValues f nil =
          ()
      | outputValues f ((eType, eTypeStr, eMsg)::values) =
          (case eType of
             generic => f ("Generic exception of type " ^ eTypeStr ^ " raised: ")
           | bug => f "Software bug: "
           | notImplemented => f "Feature has not yet been implemented: ";
           f eMsg; f "\n")

    fun output f (Generic(values)) =
          outputValues f values
      | output f _ =
          f "Software bug: gnE.output used with an exception which is not of type Generic!"

    fun checkedExec f arg failValue =
          (f arg)
             handle
               (e as Generic(_)) =>
                 (output
                    (fn str => TextIO.output (TextIO.stdErr, str))
                    e;
                  failValue)
             (* FIXME: Define the behaviour of checedExec better! *) 
             | e => (TextIO.output (TextIO.stdErr,
                       "Software bug: Unanticipated exception " ^
                       "of type: " ^ (exnName e) ^ " raised "^
                       "with the following message: " ^ (exnMessage e));
                     failValue)
  end
