(* This file is part of CodeTransformer - a tool for manipulating IDL and C++ files.
   Copyright (C) 1999 ANOQ of the Sun (alias Johnny Andersen)

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   I reserve the right to alter the license in future versions of CodeTransformer.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

   You can get this software from http://www.HardcoreProcessing.com/
   E-mail: anoq@HardcoreProcessing.com
*)

(*require "gndictionary_sig.sml";
require "gnorder_sig.sml";
require "gnstringorder.sml";
require "gntree.sml";
require "gnsearchtree.sml";
require "gntestutil_sig.sml";
require "gntestutil.sml";
require "$.basis.__list";*)

(* General functor for dictionaries. It requires
   a structure with an ordered type as key. *)
functor gnFDictionary (Key : GN_ORDER) : GN_DICTIONARY =
  struct
    structure Tree = gnTree
    structure Stree = gnFSearchTree (Key)

    exception NotImplemented
   
    type key = Key.t
    type 'a t = 'a Stree.t

    val empty = Tree.empty

    fun lookup tree key =
          Stree.lookup tree key

    fun insert tree key item =
          Stree.insert tree key item

    fun update f tree key =
          Stree.update f tree key

    val size = Tree.size

    (* Now all the really powerful functions :) *)
    (* Notice that the dicionary module is not required to
       keep any particular ordering of the items.
       That's why there's only one fold function.
       Also notice that the fold function is NOT a tree fold
       but a linear fold similar to that of a list.
       Also notice that mapToList may return the elements
       in any order, but you could use mapToList for
       generating a list of (key * sortinfo), then sort
       that list and retrieve the dictionary data
       by using the keys and the lookup function.
       That's how mapSort is implemented... *)
    fun map f dict =
          Stree.map f dict

    fun filter f dict =
          Stree.filter f dict

    fun fold f init dict =
          Stree.fold f init dict

    fun mapToList f dict =
          fold (fn (a, b) => (f a)::b) nil dict

    fun sort compare itemList =
          if true then
            raise NotImplemented
          else
            itemList (* FIXME: Make a general sort routine somewhere *)

    (* FIXME: Maybe a gnOrder.compare would be ideal to use here... *)
    fun mapSort f compare dict =
          List.map f (sort compare (mapToList (fn a => a) dict))
  end

structure gnTestDictionary :> GN_TESTER =
  struct
    structure dict = gnFDictionary(gnStringOrder);

    fun sizeEmpty () =
          let
            val a = dict.empty
            val b = dict.insert a "abc" 5
            val c = dict.insert b "def" 10
            val d = dict.insert c "ghi" 15
            val e = dict.insert d "b" 7
          in
            (dict.size a = 0) andalso (dict.size b = 1) andalso
            (dict.size d = 3) andalso (dict.size e = 4)
          end

    fun lookupInsert () =
          let
            val a = dict.empty 
            val b = dict.insert a "abc" 5
            val c = dict.insert b "def" 10
            val d = dict.insert c "ghi" 15
            val e = dict.insert d "b" 7
            val tb =
                  case dict.lookup b "abc" of
                    NONE => ~1
                  | SOME(x) => x
            val tc1 =
                  case dict.lookup c "abc" of
                    NONE => ~1
                  | SOME(x) => x
            val tc2 =
                  case dict.lookup c "def" of
                    NONE => ~1
                  | SOME(x) => x
          in
            (dict.lookup a "" = NONE) andalso
            (dict.lookup a "nothing" = NONE) andalso
            (dict.lookup b "nothing" = NONE) andalso
            (dict.lookup c "nothing" = NONE) andalso
            (dict.lookup d "nothing" = NONE) andalso
            (dict.lookup e "nothing" = NONE) andalso
            (dict.lookup e "" = NONE) andalso
            (tb = 5) andalso (tc1 = 5) andalso (tc2 = 10)
          end

    fun test () =
          gnTU.doTest [("sizeEmpty", sizeEmpty),
                       ("lookupInsert", lookupInsert)]
  end