(* This file is part of CodeTransformer - a tool for manipulating IDL and C++ files.
   Copyright (C) 1999 ANOQ of the Sun (alias Johnny Andersen)

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   I reserve the right to alter the license in future versions of CodeTransformer.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

   You can get this software from http://www.HardcoreProcessing.com/
   E-mail: anoq@HardcoreProcessing.com
*)

(* Signature for dictionaries *)
signature GN_DICTIONARY =
  sig
    type 'a t
    type key

    val empty : 'a t

    val lookup : 'a t -> key -> 'a option

    val insert : 'a t -> key -> 'a -> 'a t
    val update : ('a -> 'a) -> 'a t -> key -> 'a t

    val size : 'a t -> int

    (* Now all the really powerful functions :) *)
    (* Notice that the dicionary module is not required to
       keep any particular ordering of the items.
       That's why there's only one fold function.
       Also notice that the fold function is NOT a tree fold
       but a linear fold similar to that of a list.
       Also notice that mapToList may return the elements
       in any order, but you could use mapToList for
       generating a list of (key * sortinfo), then sort
       that list and retrieve the dictionary data
       by using the keys and the lookup function.
       That's how mapSort is implemented... *)
    val map : (key * 'a -> 'b) -> 'a t -> 'b t
    val filter : (key * 'a -> bool) -> 'a t -> 'a t
    val fold : ((key * 'a) * 'b -> 'b) -> 'b -> 'a t -> 'b

    val mapSort : (key * 'a -> 'b) ->
                  (((key * 'a) * (key * 'a)) -> order) ->
                  'a t -> 'b list
    val mapToList : (key * 'a -> 'b) -> 'a t -> 'b list
  end