(* This file is part of CodeTransformer - a tool for manipulating IDL and C++ files.
   Copyright (C) 1999 ANOQ of the Sun (alias Johnny Andersen)

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   I reserve the right to alter the license in future versions of CodeTransformer.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

   You can get this software from http://www.HardcoreProcessing.com/
   E-mail: anoq@HardcoreProcessing.com
*)

(*require "gnorder_sig.sml";
require "gnsearchtree_sig.sml";
require "gntree.sml";
require "$.basis.__list";*)

(* This is a general seach tree functor. It requires
   a structure with an ordered datatype as the key *)
functor gnFSearchTree (Key : GN_ORDER) : GN_SEARCH_TREE =
  struct
    structure Tree = gnTree
    exception Insert (* FIXME: Must be a general exception *)
   
    type key = Key.t
    type 'a t = (key * 'a) Tree.t

    fun lookup Tree.leaf _ = NONE
      | lookup (Tree.node((foundKey, item), t1, t2)) key =
          case Key.compare (key, foundKey) of
            GREATER => (lookup t1 key)
          | EQUAL => SOME (item)
          | LESS => (lookup t2 key)

    (* General internal function used for implementing
       other functions of the structure *)
    fun mapNode f Tree.leaf _ = (f Tree.leaf)
      | mapNode f (n as Tree.node(e as (foundKey, _), t1, t2)) key =
          case Key.compare (key, foundKey) of
            GREATER => (Tree.node (e, mapNode f t1 key, t2))
          | EQUAL => (f n)
          | LESS => (Tree.node (e, t1, mapNode f t2 key))

    fun fInsert value Tree.leaf =
          Tree.node (value, Tree.leaf, Tree.leaf)
      | fInsert _ (Tree.node (_, _, _)) = raise Insert

    fun insert tree key item =
          mapNode (fInsert (key, item)) tree key

    fun fUpdate f Tree.leaf = Tree.leaf
      | fUpdate f (Tree.node ((foundKey, item), t1, t2)) =
          Tree.node ((foundKey, f item), t1, t2)

    fun update f tree key = 
          mapNode (fUpdate f) tree key

    fun map f Tree.leaf = Tree.leaf
      | map f (Tree.node (e as (k, _), t1, t2)) =
          Tree.node ((k, f e), map f t1, map f t2)

    (* Notice: This is NOT a tree fold but a linear
       fold similar to fold on a list.
       I use an inorder fold but the user may not
       rely on any particular ordering of the fold. *)
    fun fold f acc tree =
          Tree.inFold f acc tree

    (* filter reconstructs the searchtree, since this
       is easiest to implement. *)
    fun fFilter f (element, acc) =
          if f element then
            element::acc
          else
            acc

    fun fBuild ((key, value), accTree) =
          insert accTree key value 

    fun filter f tree =
          List.foldl fBuild Tree.empty (fold (fFilter f) nil tree)
  end
