(* This file is part of CodeTransformer - a tool for manipulating IDL and C++ files.
   Copyright (C) 1999 ANOQ of the Sun (alias Johnny Andersen)

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   I reserve the right to alter the license in future versions of CodeTransformer.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

   You can get this software from http://www.HardcoreProcessing.com/
   E-mail: anoq@HardcoreProcessing.com
*)

(* Signature for binary search trees *)
signature GN_SEARCH_TREE =
  sig
    (* t is the treetype and 'a is the type
       of elements in the tree *)
    type 'a t
    (* type of search key for the tree *)
    type key

    (* Get the item associated with a particular key
       in a tree. The item is returned as an option
       if it is found *)
    val lookup : 'a t -> key -> 'a option

    (* Insert new key + item in the tree. An exception
       is raised if the key already exists. *)
    val insert : 'a t -> key -> 'a -> 'a t
    (* FIXME: Describe this... *)
    val update : ('a -> 'a) -> 'a t -> key -> 'a t

    (* Now all the really powerful functions :) *)
    (* Notice that the searchtree module is not required to
       keep any particular ordering of the items.
       That's why there's only one fold function.
       Also notice that the fold function is NOT a tree fold
       but a linear fold similar to that of a list. *)
    val map : (key * 'a -> 'b) -> 'a t -> 'b t
    val filter : (key * 'a -> bool) -> 'a t -> 'a t
    val fold : ((key * 'a) * 'b -> 'b) -> 'b -> 'a t -> 'b
  end