(* This file is part of CodeTransformer - a tool for manipulating IDL and C++ files.
   Copyright (C) 1999 ANOQ of the Sun (alias Johnny Andersen)

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   I reserve the right to alter the license in future versions of CodeTransformer.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

   You can get this software from http://www.HardcoreProcessing.com/
   E-mail: anoq@HardcoreProcessing.com
*)

(*require "gntree_sig.sml";
require "$.basis.__int.sml";*)

(* Structure for tree datatype. It is used to _implement_
   various kinds of trees but should not be used directly *)
structure gnTree : GN_TREE =
  struct
    datatype 'a t =
      leaf
    | node of 'a * 'a t * 'a t

    val empty = leaf

    fun treeFold _ a leaf = a
      | treeFold f a (node (elem, t1, t2)) =
          (f elem (treeFold f a t1) (treeFold f a t2))

    fun map f leaf = leaf
      | map f (node (e, t1, t2)) =
          node (f e, map f t1, map f t2)

    (* Notice: These linear folds (inorder, preorder, postorder)
       similar to foldl foldr on a list. *)
    (* I considered to add an accumulation argument to
       the treeFold function to allow for implementation
       of preorder, inorder and postorder folds, but as far as
       I can see this would always be inefficient with
       strict evaluation.
       And using foldl f init (treeFold preorder ...)
       would not be ideal either... *)
    type ('a, 'b) foldFnc = ('a * 'b -> 'b) -> 'b -> 'a t -> 'b

    fun inFold f acc leaf =
          acc
      | inFold f acc (node (e, t1, t2)) =
          inFold f (f (e, inFold f acc t1)) t2

    fun preFold f acc leaf =
          acc
      | preFold f acc (node (e, t1, t2)) =
          preFold f (preFold f (f (e, acc)) t1) t2

    fun postFold f acc leaf =
          acc
      | postFold f acc (node (e, t1, t2)) =
          f (e, postFold f (postFold f acc t1) t2)

    fun fSize _ ts1 ts2 =
          (1 + ts1 + ts2)

    fun size tree =
          (treeFold fSize 0 tree)

    fun fDepth _ ts1 ts2 =
          (1 + Int.max (ts1, ts2))

    fun depth tree =
          (treeFold fDepth 0 tree)
  end