(* This file is part of CodeTransformer - a tool for manipulating IDL and C++ files.
   Copyright (C) 1999 ANOQ of the Sun (alias Johnny Andersen)

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   I reserve the right to alter the license in future versions of CodeTransformer.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

   You can get this software from http://www.HardcoreProcessing.com/
   E-mail: anoq@HardcoreProcessing.com
*)

(* Signature for tree datatype. It only has one structure
   (gnTree) which is used to _implement_ various kinds of
   trees. gnTree should not be used directly. This signature
   only exists because gnTree may be required as functor
   arguments. *)
signature GN_TREE =
  sig
    datatype 'a t =
      leaf
    | node of 'a * 'a t * 'a t

    val empty : 'a t

    val treeFold : ('a -> 'b -> 'b -> 'b) -> 'b -> 'a t -> 'b
    val map : ('a -> 'b) -> 'a t -> 'b t

    type ('a, 'b) foldFnc = ('a * 'b -> 'b) -> 'b -> 'a t -> 'b

    (* These are linear folds (inorder, preorder and postorder) *)
    val inFold : ('a, 'b) foldFnc
    val preFold : ('a, 'b) foldFnc
    val postFold : ('a, 'b) foldFnc
    
    val size : 'a t -> int
    val depth : 'a t -> int
  end