(* This file is part of CodeTransformer - a tool for manipulating IDL and C++ files.
   Copyright (C) 1999 ANOQ of the Sun (alias Johnny Andersen)

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   I reserve the right to alter the license in future versions of CodeTransformer.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

   You can get this software from http://www.HardcoreProcessing.com/
   E-mail: anoq@HardcoreProcessing.com
*)

structure gnLexMisc =
  struct
    type linenum = int
    (* type fileRef = string ref? *)
    datatype fileLoc = fLoc of int * int (* * fileRef? *)

    fun cvtErr str pos numType =
          (gnErrorMsg.error pos
            ("error converting "^numType^" literal "^str))

    fun cvtString radix (str, pos) = 
          (case (Int.scan
                   radix
                   Substring.getc
                   (Substring.all str)) of
             NONE => ((cvtErr str pos "integer");0)
           | SOME (a, _) => a)
               handle Overflow =>
                 ((cvtErr str pos "integer");0)

    val hexStringToInt = cvtString StringCvt.HEX;
    val octStringToInt = cvtString StringCvt.OCT;
    val decStringToInt = cvtString StringCvt.DEC;

    fun decStringToReal (str, pos) =
          (case Real.fromString str of
             NONE    => ((cvtErr str pos "real");0.0)
           | SOME(a) => a)
               handle Overflow =>
                 ((cvtErr str pos "real");0.0)

    (* Trims a string by triml characters at the beginning
       of the string and trimr at the end of the string.  *)
    fun trimlr triml trimr str =
          String.substring
            (str, triml, (size str) - triml - trimr)

    (* Trims both ends of a string as you can see... *)
    fun trimEsc trim str =
          trimlr (trim+1) trim str


  end (* structure gnLexMisc *)