(* This file is part of CodeTransformer - a tool for manipulating IDL and C++ files.
   Copyright (C) 1999 ANOQ of the Sun (alias Johnny Andersen)

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   I reserve the right to alter the license in future versions of CodeTransformer.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

   You can get this software from http://www.HardcoreProcessing.com/
   E-mail: anoq@HardcoreProcessing.com
*)

structure gnRandPM : GN_RANDOM = (* Park & Miller randomizer *)
  struct
    exception Range;(* FIXME: Should be a general exception *)
  
    (* Originally from L.C.Paulson's "ML for the Working Programmer"
       second edition p.108 *)
    val a = 16807.0;
    val m = 2147483647.0;

    fun nextRandom seed =
          let
            val t = a* seed;
          in
            t - m * real (floor (t/ m))
          end;

    fun randomInRange (startRange, endRange) number =
          if Real.<= (endRange, startRange) then
            raise Range
          else
            (((number* (endRange - startRange))/ m)+ startRange);
  end

structure gnTestRandPM : GN_TESTER =
  struct
    structure rand = gnRandPM;
    
    fun nextRandom () =
          Real.== (rand.nextRandom 1622650073.0, 984943658.0)

    fun randomInRange1 () =
          let
            val a = (rand.randomInRange
                     (1000.0, 2000.0) 984943658.0);
          in
            (a >= 1000.0 andalso a <= 2000.0)
          end;

    fun randomInRange2 () =
          let val _ = rand.randomInRange (2000.0, 1000.0) 1.0;
          in false end handle Range => true;

    fun test () =
          gnTU.doTest
            [("nextRandom", nextRandom),
             ("randomInRange (result range)", randomInRange1),
             ("randomInRange (range exception)", randomInRange2)];
  end